@@ -1,7 +1,6 @@
 import argparse
 
 from rasa.cli.arguments.default_arguments import (
-    add_config_param,
     add_domain_param,
     add_stories_param,
     add_out_param,
@@ -10,9 +9,9 @@ from rasa.cli.arguments.default_arguments import (
 
 
 def set_visualize_stories_arguments(parser: argparse.ArgumentParser) -> None:
+    """Sets the CLI arguments for `rasa data visualize."""
     add_domain_param(parser)
     add_stories_param(parser)
-    add_config_param(parser)
 
     add_out_param(
         parser,
